@@ -1,5 +1,5 @@
 """ User Active Definition """
-from rowantree.common.sdk import BaseModel
+from rowantree.contracts import BaseModel
 
 
 class UserActiveGetStatus(BaseModel):
